@@ -22,7 +22,6 @@
 #include <glibmmconfig.h>
 #include <glibmm/refptr.h>
 #include <glibmm/ustring.h>
-#include <glibmm/variant.h>
 #include <glibmm/wrap.h>
 #include <glibmm/debug.h>
 #include <glib-object.h>
@@ -43,10 +42,10 @@ namespace Glib
 /**
  * @ingroup ContHandles
  */
-
+ 
 //! Ownership of the container
-/*! Defines how and if the container will release the list and
- * its elemens when it is destroyed
+/*! Defines how and if the container will release the list and 
+ * its elemens when it is destroyed 
  */
 enum OwnershipType
 {
@@ -75,7 +74,7 @@ public:
 
   Iterator begin() const { return pbegin_; }
   Iterator end()   const { return pend_;   }
-  std::size_t size()  const { return std::distance(pbegin_, pend_); }
+  size_t   size()  const { return std::distance(pbegin_, pend_); }
 };
 
 /** Helper function to create a Glib::Sequence<> object, which
@@ -121,7 +120,7 @@ struct TypeTraits
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS /* hide the specializations */
 
-//For some (probably, more spec-compliant) compilers, these specializations must
+//For some (proably, more spec-compliant) compilers, these specializations must
 //be next to the objects that they use.
 #ifdef GLIBMM_CAN_USE_DYNAMIC_CAST_IN_UNUSED_TEMPLATE_WITHOUT_DEFINITION
 
@@ -146,7 +145,7 @@ struct TypeTraits<T*>
     GObject* cobj = (GObject*)ptr;
     return dynamic_cast<CppType>(Glib::wrap_auto(cobj, false /* take_copy */));
   }
-
+  
   static void    release_c_type (CType   ptr)
   {
     GLIBMM_DEBUG_UNREFERENCE(0, ptr);
@@ -155,7 +154,7 @@ struct TypeTraits<T*>
 };
 
 //This confuse the SUN Forte compiler, so we ifdef it out:
-#ifdef GLIBMM_HAVE_DISAMBIGUOUS_CONST_TEMPLATE_SPECIALIZATIONS
+#ifdef GLIBMM_HAVE_DISAMBIGUOUS_CONST_TEMPLATE_SPECIALIZATIONS 
 
 /** Partial specialization for pointers to const GtkObject instances.
  * @ingroup ContHelpers
@@ -178,7 +177,7 @@ struct TypeTraits<const T*>
      GObject* cobj = (GObject*)const_cast<CTypeNonConst>(ptr);
      return dynamic_cast<CppType>(Glib::wrap_auto(cobj, false /* take_copy */));
   }
-
+  
   static void    release_c_type (CType   ptr)
   {
     GLIBMM_DEBUG_UNREFERENCE(0, ptr);
@@ -208,11 +207,11 @@ struct TypeTraits< Glib::RefPtr<T> >
     //because we can not use a specific Glib::wrap(CType) overload here,
     //because that would be "dependent", and g++ 3.4 does not allow that.
     //The specific Glib::wrap() overloads don't do anything special anyway.
-    GObject* cobj = (GObject*)(ptr);
+    GObject* cobj = (GObject*)const_cast<CTypeNonConst>(ptr);
     return Glib::RefPtr<T>( dynamic_cast<T*>(Glib::wrap_auto(cobj, true /* take_copy */)) );
     //We use dynamic_cast<> in case of multiple inheritance.
   }
-
+  
   static void    release_c_type (CType          ptr)
   {
     GLIBMM_DEBUG_UNREFERENCE(0, ptr);
@@ -244,11 +243,11 @@ struct TypeTraits< Glib::RefPtr<const T> >
     //because we can not use a specific Glib::wrap(CType) overload here,
     //because that would be "dependent", and g++ 3.4 does not allow that.
     //The specific Glib::wrap() overloads don't do anything special anyway.
-    GObject* cobj = (GObject*)const_cast<CTypeNonConst>(ptr);
+    GObject* cobj = (GObject*)(ptr);
     return Glib::RefPtr<const T>( dynamic_cast<const T*>(Glib::wrap_auto(cobj, true /* take_copy */)) );
     //We use dynamic_cast<> in case of multiple inheritance.
   }
-
+  
   static void    release_c_type (CType          ptr)
   {
     GLIBMM_DEBUG_UNREFERENCE(0, ptr);
@@ -324,51 +323,6 @@ struct TypeTraits<bool>
   static void    release_c_type (CType) {}
 };
 
-/** Specialization for Glib::VariantBase.
- * @ingroup ContHelpers
- */
-template <>
-struct TypeTraits<Glib::VariantBase>
-{
-  typedef Glib::VariantBase     CppType;
-  typedef GVariant *            CType;
-  typedef GVariant *            CTypeNonConst;
-
-  static CType to_c_type (const Glib::VariantBase& v)
-    { return const_cast<CTypeNonConst>(v.gobj()); }
-
-  static CType to_c_type (CType v) { return v; }
-
-  static CppType to_cpp_type(CType v)
-    { return Glib::VariantBase(v, true); }
-
-  static void release_c_type(CType v)
-    { g_variant_unref(const_cast<CTypeNonConst>(v)); }
-};
-
-/** Specialization for Glib::VariantContainerBase.
- * @ingroup ContHelpers
- */
-template <>
-struct TypeTraits<Glib::VariantContainerBase>
-{
-  typedef Glib::VariantContainerBase    CppType;
-  typedef GVariant *                    CType;
-  typedef GVariant *                    CTypeNonConst;
-
-  static CType to_c_type (const Glib::VariantContainerBase& v)
-    { return const_cast<CTypeNonConst>(v.gobj()); }
-
-  static CType to_c_type (CType v) { return v; }
-
-  static CppType to_cpp_type(CType v)
-    { return Glib::VariantContainerBase(v, true); }
-
-  static void release_c_type(CType v)
-    { g_variant_unref(const_cast<CTypeNonConst>(v)); }
-};
-
-
 #ifndef GLIBMM_HAVE_TEMPLATE_SEQUENCE_CTORS
 
 /* The STL containers in Sun's libCstd don't support templated sequence
